@@ -30,4 +30,4 @@ ub<-seuil+seuil*tolerance
 cat("computing...", "\n")
 ef_prime.boot<-boot(ef, thinning, R=nrandom,ub=ub,lb=lb)
 cat("done", "\n")
-return(list(mean.boot=mean(ef_prime.boot$t),sd.boot=sd(ef_prime.boot$t)))}
\ No newline at end of file
+return(list(mean.boot=mean(ef_prime.boot$t),sd.boot=sd(as.vector(ef_prime.boot$t))))}
\ No newline at end of file
