@@ -3,7 +3,7 @@
 ## Copyright 2010-2012 Jean-Pierre Rossi
 ## This file is part of the R-package `rich'.
 
-.First.lib <- function(lib, pkg)  {
+.onLoad <- function(lib, pkg)  {
 packageStartupMessage("This is rich ",
                            utils::packageDescription("rich", field="Version"),
                            appendLF = TRUE)}
